# coding: utf-8

# flake8: noqa

"""
    URLR API Reference

    API powering the features of URLR.<br><br>Note that in order to facilitate integration, we provide SDKs for various languages at https://github.com/URLR.<br><br>Key API principles:<br>         <ul><li>All dates follow **ISO-8601** format</li><li>Most errors follow **RFC 9457** standard</li><li>All responses are delivered in English</li></ul>

    The version of the OpenAPI document: 1.5
    Contact: contact@urlr.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "2.7.0"

# import apis into sdk package
from urlr.api.access_tokens_api import AccessTokensApi
from urlr.api.folders_api import FoldersApi
from urlr.api.links_api import LinksApi
from urlr.api.qr_codes_api import QRCodesApi
from urlr.api.statistics_api import StatisticsApi
from urlr.api.teams_api import TeamsApi

# import ApiClient
from urlr.api_response import ApiResponse
from urlr.api_client import ApiClient
from urlr.configuration import Configuration
from urlr.exceptions import OpenApiException
from urlr.exceptions import ApiTypeError
from urlr.exceptions import ApiValueError
from urlr.exceptions import ApiKeyError
from urlr.exceptions import ApiAttributeError
from urlr.exceptions import ApiException

# import models into sdk package
from urlr.models.create_access_token200_response import CreateAccessToken200Response
from urlr.models.create_access_token401_response import CreateAccessToken401Response
from urlr.models.create_access_token_request import CreateAccessTokenRequest
from urlr.models.create_link429_response import CreateLink429Response
from urlr.models.create_link500_response import CreateLink500Response
from urlr.models.create_link_request import CreateLinkRequest
from urlr.models.create_link_request_metatag import CreateLinkRequestMetatag
from urlr.models.create_link_request_qrcode import CreateLinkRequestQrcode
from urlr.models.create_qr_code_request import CreateQrCodeRequest
from urlr.models.create_qr_code_request_one_of import CreateQrCodeRequestOneOf
from urlr.models.create_qr_code_request_one_of1 import CreateQrCodeRequestOneOf1
from urlr.models.get_folders200_response import GetFolders200Response
from urlr.models.get_folders200_response_folders_inner import GetFolders200ResponseFoldersInner
from urlr.models.get_link200_response import GetLink200Response
from urlr.models.get_link200_response_geolinks_inner import GetLink200ResponseGeolinksInner
from urlr.models.get_link200_response_metatag import GetLink200ResponseMetatag
from urlr.models.get_link200_response_qrcode import GetLink200ResponseQrcode
from urlr.models.get_link200_response_utm import GetLink200ResponseUtm
from urlr.models.get_link401_response import GetLink401Response
from urlr.models.get_link404_response import GetLink404Response
from urlr.models.get_link422_response import GetLink422Response
from urlr.models.get_statistics200_response import GetStatistics200Response
from urlr.models.get_statistics_request import GetStatisticsRequest
from urlr.models.get_teams200_response import GetTeams200Response
from urlr.models.get_teams200_response_teams_inner import GetTeams200ResponseTeamsInner
from urlr.models.refresh_access_token401_response import RefreshAccessToken401Response
from urlr.models.refresh_access_token_request import RefreshAccessTokenRequest



# coding: utf-8

"""
    URLR API Reference

    API powering the features of URLR.<br><br>Note that in order to facilitate integration, we provide SDKs for various languages at https://github.com/URLR.<br><br>Key API principles:<br>         <ul><li>All dates follow **ISO-8601** format</li><li>Most errors follow **RFC 9457** standard</li><li>All responses are delivered in English</li></ul>

    The version of the OpenAPI document: 1.5
    Contact: contact@urlr.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class CreateLinkRequestQrcode(BaseModel):
    """
    QR Code
    """ # noqa: E501
    size: Optional[Annotated[int, Field(le=1000, strict=True, ge=100)]] = Field(default=600, description="The size of the QR code (px)")
    format: Optional[StrictStr] = Field(default='png', description="The format of the QR code")
    margin: Optional[StrictInt] = Field(default=0, description="The margin around the QR code (px)")
    background_color: Optional[StrictStr] = Field(default='#ffffff', description="The background color of the QR code (hexadecimal)")
    foreground_color: Optional[StrictStr] = Field(default='#000000', description="The foreground color of the QR code (hexadecimal)")
    __properties: ClassVar[List[str]] = ["size", "format", "margin", "background_color", "foreground_color"]

    @field_validator('format')
    def format_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['png', 'webp', 'svg']):
            raise ValueError("must be one of enum values ('png', 'webp', 'svg')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CreateLinkRequestQrcode from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CreateLinkRequestQrcode from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "size": obj.get("size") if obj.get("size") is not None else 600,
            "format": obj.get("format") if obj.get("format") is not None else 'png',
            "margin": obj.get("margin") if obj.get("margin") is not None else 0,
            "background_color": obj.get("background_color") if obj.get("background_color") is not None else '#ffffff',
            "foreground_color": obj.get("foreground_color") if obj.get("foreground_color") is not None else '#000000'
        })
        return _obj





# coding: utf-8

"""
    URLR API Reference

    API powering the features of URLR.<br><br>Note that in order to facilitate integration, we provide SDKs for various languages at https://github.com/URLR.<br><br>Key API principles:<br>         <ul><li>All dates follow **ISO-8601** format</li><li>Most errors follow **RFC 9457** standard</li><li>All responses are delivered in English</li></ul>

    The version of the OpenAPI document: 1.5
    Contact: contact@urlr.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from urlr.models.get_link200_response import GetLink200Response

class TestGetLink200Response(unittest.TestCase):
    """GetLink200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetLink200Response:
        """Test GetLink200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetLink200Response`
        """
        model = GetLink200Response()
        if include_optional:
            return GetLink200Response(
                id = '436b5d20-e174-4363-94e5-2b3dd4e74b5f',
                url = '',
                team_id = '',
                folder_id = '',
                domain = 'urlr.me',
                code = 'xxxxx',
                label = '',
                qrcode = urlr.models.get_link_200_response_qrcode.getLink_200_response_qrcode(
                    data = '', ),
                utm = urlr.models.get_link_200_response_utm.getLink_200_response_utm(
                    campaign = '', 
                    medium = '', 
                    source = '', 
                    content = '', ),
                metatag = urlr.models.get_link_200_response_metatag.getLink_200_response_metatag(
                    title = '', 
                    description = '', 
                    image = '', ),
                geolinks = [
                    urlr.models.get_link_200_response_geolinks_inner.getLink_200_response_geolinks_inner(
                        type = '', 
                        value = '', 
                        url = '', )
                    ],
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                expired_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                expired_url = '',
                delete_after_expiration = True
            )
        else:
            return GetLink200Response(
        )
        """

    def testGetLink200Response(self):
        """Test GetLink200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    URLR API Reference

    API powering the features of URLR.<br><br>Note that in order to facilitate integration, we provide SDKs for various languages at https://github.com/URLR.<br><br>Key API principles:<br>         <ul><li>All dates follow **ISO-8601** format</li><li>Most errors follow **RFC 9457** standard</li><li>All responses are delivered in English</li></ul>

    The version of the OpenAPI document: 1.5
    Contact: contact@urlr.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from urlr.api.links_api import LinksApi


class TestLinksApi(unittest.TestCase):
    """LinksApi unit test stubs"""

    def setUp(self) -> None:
        self.api = LinksApi()

    def tearDown(self) -> None:
        pass

    def test_create_link(self) -> None:
        """Test case for create_link

        Create a link
        """
        pass

    def test_get_link(self) -> None:
        """Test case for get_link

        Get a link
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    URLR API Reference

    API powering the features of URLR.<br><br>Note that in order to facilitate integration, we provide SDKs for various languages at https://github.com/URLR.<br><br>Key API principles:<br>         <ul><li>All dates follow **ISO-8601** format</li><li>Most errors follow **RFC 9457** standard</li><li>All responses are delivered in English</li></ul>

    The version of the OpenAPI document: 1.5
    Contact: contact@urlr.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from urlr.models.create_access_token200_response import CreateAccessToken200Response
from urlr.models.create_access_token401_response import CreateAccessToken401Response
from urlr.models.create_access_token_request import CreateAccessTokenRequest
from urlr.models.create_link429_response import CreateLink429Response
from urlr.models.create_link500_response import CreateLink500Response
from urlr.models.create_link_request import CreateLinkRequest
from urlr.models.create_link_request_metatag import CreateLinkRequestMetatag
from urlr.models.create_link_request_qrcode import CreateLinkRequestQrcode
from urlr.models.create_qr_code_request import CreateQrCodeRequest
from urlr.models.create_qr_code_request_one_of import CreateQrCodeRequestOneOf
from urlr.models.create_qr_code_request_one_of1 import CreateQrCodeRequestOneOf1
from urlr.models.get_folders200_response import GetFolders200Response
from urlr.models.get_folders200_response_folders_inner import GetFolders200ResponseFoldersInner
from urlr.models.get_link200_response import GetLink200Response
from urlr.models.get_link200_response_geolinks_inner import GetLink200ResponseGeolinksInner
from urlr.models.get_link200_response_metatag import GetLink200ResponseMetatag
from urlr.models.get_link200_response_qrcode import GetLink200ResponseQrcode
from urlr.models.get_link200_response_utm import GetLink200ResponseUtm
from urlr.models.get_link401_response import GetLink401Response
from urlr.models.get_link404_response import GetLink404Response
from urlr.models.get_link422_response import GetLink422Response
from urlr.models.get_statistics200_response import GetStatistics200Response
from urlr.models.get_statistics_request import GetStatisticsRequest
from urlr.models.get_teams200_response import GetTeams200Response
from urlr.models.get_teams200_response_teams_inner import GetTeams200ResponseTeamsInner
from urlr.models.refresh_access_token401_response import RefreshAccessToken401Response
from urlr.models.refresh_access_token_request import RefreshAccessTokenRequest



# coding: utf-8

"""
    URLR API Reference

    API powering the features of URLR.<br><br>Note that in order to facilitate integration, we provide SDKs for various languages at https://github.com/URLR.<br><br>Key API principles:<br>         <ul><li>All dates follow **ISO-8601** format</li><li>Most errors follow **RFC 9457** standard</li><li>All responses are delivered in English</li></ul>

    The version of the OpenAPI document: 1.5
    Contact: contact@urlr.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from urlr.models.get_link200_response_geolinks_inner import GetLink200ResponseGeolinksInner
from urlr.models.get_link200_response_metatag import GetLink200ResponseMetatag
from urlr.models.get_link200_response_qrcode import GetLink200ResponseQrcode
from urlr.models.get_link200_response_utm import GetLink200ResponseUtm
from typing import Optional, Set
from typing_extensions import Self

class GetLink200Response(BaseModel):
    """
    GetLink200Response
    """ # noqa: E501
    id: Optional[StrictStr] = Field(default=None, description="Link API ID")
    url: Optional[StrictStr] = Field(default=None, description="Original URL")
    team_id: Optional[StrictStr] = Field(default=None, description="Team API ID")
    folder_id: Optional[StrictStr] = Field(default=None, description="Folder API ID")
    domain: Optional[StrictStr] = Field(default=None, description="Domain")
    code: Optional[StrictStr] = Field(default=None, description="Short code")
    label: Optional[StrictStr] = Field(default=None, description="Label")
    qrcode: Optional[GetLink200ResponseQrcode] = None
    utm: Optional[GetLink200ResponseUtm] = None
    metatag: Optional[GetLink200ResponseMetatag] = None
    geolinks: Optional[List[GetLink200ResponseGeolinksInner]] = Field(default=None, description="Geographical targeting links")
    created_at: Optional[datetime] = Field(default=None, description="Creation date")
    updated_at: Optional[datetime] = Field(default=None, description="Modification date")
    expired_at: Optional[datetime] = Field(default=None, description="Expiration date")
    expired_url: Optional[StrictStr] = Field(default=None, description="Expiration URL")
    delete_after_expiration: Optional[StrictBool] = Field(default=False, description="Whether or not to remove the link after the expiry date")
    __properties: ClassVar[List[str]] = ["id", "url", "team_id", "folder_id", "domain", "code", "label", "qrcode", "utm", "metatag", "geolinks", "created_at", "updated_at", "expired_at", "expired_url", "delete_after_expiration"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of GetLink200Response from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of qrcode
        if self.qrcode:
            _dict['qrcode'] = self.qrcode.to_dict()
        # override the default output from pydantic by calling `to_dict()` of utm
        if self.utm:
            _dict['utm'] = self.utm.to_dict()
        # override the default output from pydantic by calling `to_dict()` of metatag
        if self.metatag:
            _dict['metatag'] = self.metatag.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in geolinks (list)
        _items = []
        if self.geolinks:
            for _item_geolinks in self.geolinks:
                if _item_geolinks:
                    _items.append(_item_geolinks.to_dict())
            _dict['geolinks'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of GetLink200Response from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "url": obj.get("url"),
            "team_id": obj.get("team_id"),
            "folder_id": obj.get("folder_id"),
            "domain": obj.get("domain"),
            "code": obj.get("code"),
            "label": obj.get("label"),
            "qrcode": GetLink200ResponseQrcode.from_dict(obj["qrcode"]) if obj.get("qrcode") is not None else None,
            "utm": GetLink200ResponseUtm.from_dict(obj["utm"]) if obj.get("utm") is not None else None,
            "metatag": GetLink200ResponseMetatag.from_dict(obj["metatag"]) if obj.get("metatag") is not None else None,
            "geolinks": [GetLink200ResponseGeolinksInner.from_dict(_item) for _item in obj["geolinks"]] if obj.get("geolinks") is not None else None,
            "created_at": obj.get("created_at"),
            "updated_at": obj.get("updated_at"),
            "expired_at": obj.get("expired_at"),
            "expired_url": obj.get("expired_url"),
            "delete_after_expiration": obj.get("delete_after_expiration") if obj.get("delete_after_expiration") is not None else False
        })
        return _obj





# flake8: noqa

# import apis into api package
from urlr.api.access_tokens_api import AccessTokensApi
from urlr.api.folders_api import FoldersApi
from urlr.api.links_api import LinksApi
from urlr.api.qr_codes_api import QRCodesApi
from urlr.api.statistics_api import StatisticsApi
from urlr.api.teams_api import TeamsApi




# coding: utf-8

"""
    URLR API Reference

    API powering the features of URLR.<br><br>Note that in order to facilitate integration, we provide SDKs for various languages at https://github.com/URLR.<br><br>Key API principles:<br>         <ul><li>All dates follow **ISO-8601** format</li><li>Most errors follow **RFC 9457** standard</li><li>All responses are delivered in English</li></ul>

    The version of the OpenAPI document: 1.5
    Contact: contact@urlr.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from setuptools import setup, find_packages  # noqa: H301

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools
NAME = "urlr"
VERSION = "2.7.0"
PYTHON_REQUIRES = ">= 3.8"
REQUIRES = [
    "urllib3 >= 1.25.3, < 3.0.0",
    "python-dateutil >= 2.8.2",
    "pydantic >= 2",
    "typing-extensions >= 4.7.1",
]

setup(
    name=NAME,
    version=VERSION,
    description="Python client for URLR",
    author="URLR",
    author_email="contact@urlr.me",
    url="",
    keywords=["link shortener", "api", "sdk", "client"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    license="MIT",
    long_description_content_type='text/markdown',
    long_description="""\
    API powering the features of URLR.&lt;br&gt;&lt;br&gt;Note that in order to facilitate integration, we provide SDKs for various languages at https://github.com/URLR.&lt;br&gt;&lt;br&gt;Key API principles:&lt;br&gt;         &lt;ul&gt;&lt;li&gt;All dates follow **ISO-8601** format&lt;/li&gt;&lt;li&gt;Most errors follow **RFC 9457** standard&lt;/li&gt;&lt;li&gt;All responses are delivered in English&lt;/li&gt;&lt;/ul&gt;
    """,  # noqa: E501
    package_data={"urlr": ["py.typed"]},
)


# coding: utf-8

"""
    URLR API Reference

    API powering the features of URLR.<br><br>Note that in order to facilitate integration, we provide SDKs for various languages at https://github.com/URLR.<br><br>Key API principles:<br>         <ul><li>All dates follow **ISO-8601** format</li><li>Most errors follow **RFC 9457** standard</li><li>All responses are delivered in English</li></ul>

    The version of the OpenAPI document: 1.5
    Contact: contact@urlr.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from urlr.models.create_link_request_metatag import CreateLinkRequestMetatag

class TestCreateLinkRequestMetatag(unittest.TestCase):
    """CreateLinkRequestMetatag unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateLinkRequestMetatag:
        """Test CreateLinkRequestMetatag
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateLinkRequestMetatag`
        """
        model = CreateLinkRequestMetatag()
        if include_optional:
            return CreateLinkRequestMetatag(
                title = '',
                description = '',
                image = ''
            )
        else:
            return CreateLinkRequestMetatag(
        )
        """

    def testCreateLinkRequestMetatag(self):
        """Test CreateLinkRequestMetatag"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
